body{margin:0;background:#FAFAFA}a{color:#70b0ff;text-decoration:none}body,html{box-sizing:border-box}*,*:before,*:after{font-family:Inter-Display,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;box-sizing:inherit}
